// C VISA Signal Generator Example
// To compile this example:
// - add the VISA include path to the compiler's include paths( IVI installation folder, e.g.
//   "C:\Program Files (x86)\IVI Foundation\VISA\WinNT\include"
// - add the visa32.lib file to the linker's depedencies (IVI installation folder, e.g.
//   "C:\Program Files (x86)\IVI Foundation\VISA\WinNT\lib\msc\visa32.lib")

#include <string.h>
#include <stdio.h>
#include "visa.h"

#define DEVICES_BUFFER_SIZE 1000
#define BUFFER_SIZE 1000
#define MAX_DEVICES 20

int main(void)
{
	ViStatus status; /* For checking errors */
	ViSession defaultRM, instr;/* Communication channels */
	ViChar buffer[BUFFER_SIZE]; /* Buffer for string I/O */ 
	ViInt32 blockSize;

	// Initializa VISA resource manager
	status = viOpenDefaultRM(&defaultRM);
	if (status < VI_SUCCESS) {
		return -1;
	}

	// Open link
	status = viOpen(defaultRM, "TCPIP0::192.168.1.199::inst0::INSTR", VI_NULL, VI_NULL, &instr);

	// Set communication timeout
	status = viSetAttribute(instr, VI_ATTR_TMO_VALUE, 2000);

	// Query "*IDN?"
	status = viPrintf(instr, "*IDN?\n");
	status = viScanf(instr, "%[^\n]\n", buffer);
	printf("*IDN? response:\n  %s\n", buffer);

	// Send sweep list
	sprintf_s(buffer,
		      BUFFER_SIZE,
			  "11e6;0.0;1.0;1.0\n"
			  "22e6;0.0;1.0;1.0\n"
			  "33e6;0.0;1.0;1.0\n"
			  "44e6;0.0;1.0;1.0\n"
			  "55e6;0.0;1.0;1.0\n");
	blockSize = strlen(buffer);
	status = viPrintf(instr, "MEM:FILE:LIST:DATA %*b\n", blockSize, buffer);

	// Query sent list's number of points
	status = viPrintf(instr, "LIST:CURR:POIN?\n");
	status = viScanf(instr, "%[^\n]\n", buffer);
	printf("Device received %s points list\n\n", buffer);

	// Receive processed sweep list
	status = viPrintf(instr, "MEM:FILE:LIST:DATA?\n");
	viScanf(instr, "%#b", &blockSize, buffer);
	buffer[blockSize] = '\0';
	printf("Processed list data:\n%s", buffer);

	// Close link
	status = viClose(instr);
	status = viClose(defaultRM);
	
	getchar();
	return 0;
}

